from decouple import config
import requests
import json
import logging

logger = logging.getLogger(__name__)
api_url = str(config("SMS_API_URL", cast=str, default=""))
api_key = str(config("SMS_API_KEY", cast=str, default=""))


def send_otp(mobile: str, otp: str, message: str):
    if not api_url or not api_key:
        logger.debug("Failed to send SMS. Missing SMS_API_URL or SMS_API_KEY.")
        return False

    headers = {
        "Content-Type": "application/json",
        "Authorization": f"Bearer {api_key}",
    }
    data = {
        "number": mobile,
        "message": message,
        "check_delivery": False,
    }
    response = requests.post(api_url, headers=headers, data=json.dumps(data))
    if response.status_code == 200:
        return True
    else:
        logger.debug(f"Failed to send SMS. Status code: {response.status_code}")
        return False


def send_sms(mobile: str, message: str):
    logger.info(f"Sending SMS to {mobile}")
    try:
        if not api_url or not api_key:
            logger.debug("Failed to send SMS. Missing SMS_API_URL or SMS_API_KEY.")
            return False

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {api_key}",
        }
        data = {
            "number": mobile,
            "message": message,
            "check_delivery": False,
        }
        response = requests.post(api_url, headers=headers, data=json.dumps(data))
        if response.status_code == 200:
            return True
        else:
            logger.debug(f"Failed to send SMS. Status code: {response.status_code}")
            return False
    except requests.exceptions.RequestException as e:
        logger.debug(f"Failed to send SMS. Error: {e}")
        return False
